@@ -78,8 +78,9 @@
         if (any(noInst))
             .warning(
                 paste(
-                    "package(s) not installed when version(s) same",
-                    "as current; use `force = TRUE` to re-install: \n'%s'"
+                    "package(s) not installed when version(s) same as or",
+                    "greater than current; use `force = TRUE` to re-install: ",
+                    "\n'%s'"
                 ),
                 paste(pkgs[noInst], collapse = "' '")
             )
@@ -126,8 +127,7 @@
 }
 
 .install_repos <-
-    function(pkgs, old_pkgs, instPkgs, lib, repos, type = getOption("pkgType"),
-             force, ...)
+    function(pkgs, old_pkgs, instPkgs, lib, repos, force, ...)
 {
     doing <- .install_filter_up_to_date(
         pkgs = pkgs, instPkgs = instPkgs, old_pkgs = old_pkgs, force = force
@@ -143,9 +143,10 @@
 }
 
 .install_github <-
-    function(pkgs, lib, lib.loc, repos, force, ...)
+    function(pkgs, lib, lib.loc, repos, update, ask, force, ...)
 {
     doing <- .install_filter_github_repos(pkgs)
+    ask <- if (!update) "never" else if (update && !ask) "always" else "default"
 
     oopts <- options(repos = repos)     # required by remotes::
     on.exit(options(oopts))
@@ -154,7 +155,9 @@
         .message("Installing github package(s) %s", pkgNames)
         .install_github_load_remotes(pkgs, lib.loc = lib.loc)
         for (repo in doing)
-            remotes::install_github(repo, lib = lib, force = force, ...)
+            remotes::install_github(
+                repo, lib = lib, upgrade = ask, force = force, ...
+            )
     }
     setdiff(pkgs, doing)
 }
@@ -190,7 +193,7 @@
 
 .install <-
     function(pkgs, old_pkgs, instPkgs, repos, lib.loc=NULL, lib=.libPaths()[1],
-        checkBuilt, force, ...)
+        checkBuilt, update, ask, force, ...)
 {
     requireNamespace("utils", quietly=TRUE) ||
         .stop("failed to load package 'utils'")
@@ -200,7 +203,8 @@
         checkBuilt = checkBuilt, force = force, ...
     )
     todo <- .install_github(
-        todo, lib = lib, lib.loc = lib.loc, repos = repos, force = force, ...
+        todo, lib = lib, lib.loc = lib.loc, repos = repos,
+        update = update, ask = ask, force = force, ...
     )
 
     if (length(todo))
@@ -245,7 +249,7 @@
 }
 
 .install_updated_version <-
-    function(valid, update, repos, ...)
+    function(valid, update, old_pkgs, instPkgs, repos, force, ...)
 {
     if (isTRUE(valid))
         return(valid)
@@ -255,7 +259,7 @@
     if (is.null(pkgs) || !update)
         return(pkgs)
 
-    .install(pkgs, repos, ...)
+    .install(pkgs, old_pkgs, instPkgs, repos, force = force, ...)
     pkgs
 }
 
@@ -424,12 +428,15 @@ install <-
 
     pkgs <- .install(
         pkgs, vout[["out_of_date"]], instPkgs = inst, repos = repos,
-        checkBuilt = checkBuilt, force = force, ...
+        checkBuilt = checkBuilt, update = update, ask = ask, force = force, ...
     )
     if (update && cmp == 0L) {
         .install_update(repos, ask, checkBuilt = checkBuilt, ...)
     } else if (cmp != 0L) {
-        .install_updated_version(valist, update, repos, ...)
+        .install_updated_version(
+            valist, update, vout[["out_of_date"]], inst, repos, force = force,
+            ...
+        )
     }
 
     invisible(pkgs)
